#!/bin/bash
#set -x

usage ()
{
  echo 'Usage : launcher.sh [ --ip <3g | eth0> ] [ --os ] [ --pkg-info  <package> ] [ --pkg-upgrade <package> ] [ --tunnel ] [ --get-instance ] [ --get-sn ]'
  exit
}
#################################################################
while [ "$1" != "" ]; do
case $1 in
        --ip )         		shift
                      		INTERFACE=$1
                       		;;
        --os )        		OS=1
                       		;;
        --pkg-info )        	shift
                       		PKG_INF=$1
                       		;;
	--pkg-upgrade )		shift
				PKG=$1
				;;
	--tunnel )		TUNNEL=1
				;;
	--get-instance )
				GET_INST=1
				;;
	--get-sn )		SN=1
				;;
        * )
				usage
    esac
    shift
done

##################################################################

DT_COMPAT_LIST=`tr < /proc/device-tree/compatible  '\000' '\n'`

    for compat in $DT_COMPAT_LIST; do
        case "$compat" in
            "onion,omega2p" )
                INSPARK_HW_VERSION=SmartMetrix;
                break;
            ;;
            "mub" )
                INSPARK_HW_VERSION=milandr;
                break;
            ;;

	    "inspark,imx28-inspark55" | "contactless,imx28-wirenboard55" )
     		INSPARK_HW_VERSION=imx287;
                break;
            ;;

        esac
    done;

###############################################################
PKG_MAN='apt-get'
#SSH_SERVER='smart-metrix@jampserver.inspark.ru'
SSH_SERVER='root@jumpserver.inspark.ru'
SSH_PORT=30022
###############################################################

function pkg_manager_check()
{
if [[ -f /bin/opkg ]]; then
	PKG_MAN='opkg'
	OS_VER=wrt
fi
}

function pkg_ver()
{
if [[ $OS_VER == 'wrt' ]]; then
	 /usr/bin/mosquitto_pub -t "/Controller/Out/Inventory" -m "$PKG_INF `opkg status $PKG_INF | awk '/Version/{print $2}'`	"
else
	 /usr/bin/mosquitto_pub -t "/Controller/Out/Inventory" -m " $PKG_INF `dpkg -l $PKG_INF | awk '/ii/{print $3}'`"
fi
}

function install()
{
$PKG_MAN update && $PKG_MAN install $1 > /dev/null 2>&1
}

function tunnel()
{
        ssh -fNMS /tmp/ssh_socket -p $1 $2
        ssh -S /tmp/ssh_socket -O check placeholder
        /usr/bin/mosquitto_pub -t "/Controller/Out/Inventory" -m "SSH Port `ssh -S /tmp/ssh_socket -O forward -R 0:localhost:22 placeholder`"
        ssh -S /tmp/ssh_socket -O forward -R 0:localhost:22 placeholder
	sleep 600
	ssh -S /tmp/ssh_socket -O cancel -R 0:localhost:22 placeholder
}

function get_instance ()
{
	INSTANCE=`cat /etc/mosquitto/conf.d/bridge.conf | awk -F/ '/Measure/{print $5}'`
	[[ -z "$INSTANCE" ]] || /usr/bin/mosquitto_pub -t "/Controller/Out/Inventory" -m "Instance $INSTANCE"
}

function get_sn ()
{
        /usr/bin/mosquitto_pub -t "/Controller/Out/Inventory" -m "SerialNumber `cat /var/inspark/vsn`"
}

################################################################
pkg_manager_check
[[ -z "$PKG_INF" ]] || ( pkg_ver )
#[[ -z "$INTERFACE" ]] || ( /usr/bin/mosquitto_pub -t "/Controller/Out/$INTERFACE" -m `ip addr show $INTERFACE |  awk '/inet /{print $2}' ` )
[[ -z "$OS" ]] || (  /usr/bin/mosquitto_pub -t "/Controller/Out/Inventory/OS Version" -m `cat /etc/os-release | awk -F= '/VERSION=/{print $2}'` )
[[ -z "$PKG" ]] || ( install $PKG )
[[ -z "$TUNNEL" ]] || ( tunnel $SSH_PORT $SSH_SERVER )
[[ -z "$GET_INST" ]] || ( get_instance )
[[ -z "$SN" ]] || ( get_sn )

